==> libreoffice_7.4.7.orig.tar.xz: libreoffice-7.4.7.2/vcl/source/pdf/PDFiumTools.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 */

#include <vcl/filter/PDFiumLibrary.hxx>

namespace vcl::pdf
{
OUString convertPdfDateToISO8601(OUString const& rInput)
{
    if (rInput.getLength() < 6)
        return {};

    std::u16string_view prefix = rInput.subView(0, 2);
    if (prefix != u"D:")
        return {};

    std::u16string_view sYear = rInput.subView(2, 4);

    std::u16string_view sMonth(u"01");
    if (rInput.getLength() >= 8)
        sMonth = rInput.subView(6, 2);

    std::u16string_view sDay(u"01");
    if (rInput.getLength() >= 10)
        sDay = rInput.subView(8, 2);

    std::u16string_view sHours(u"00");
    if (rInput.getLength() >= 12)
        sHours = rInput.subView(10, 2);

    std::u16string_view sMinutes(u"00");
    if (rInput.getLength() >= 14)
        sMinutes = rInput.subView(12, 2);

    std::u16string_view sSeconds(u"00");
    if (rInput.getLength() >= 16)
        sSeconds = rInput.subView(14, 2);

    OUString sTimeZoneMark("Z");
    if (rInput.getLength() >= 17)
        sTimeZoneMark = rInput.subView(16, 1);

    std::u16string_view sTimeZoneHours(u"00");
    std::u16string_view sTimeZoneMinutes(u"00");
    if ((sTimeZoneMark == "+" || sTimeZoneMark == "-") && rInput.getLength() >= 22)
    {
        std::u16string_view sTimeZoneSeparator = rInput.subView(19, 1);
        if (sTimeZoneSeparator == u"'")
        {
            sTimeZoneHours = rInput.subView(17, 2);
            sTimeZoneMinutes = rInput.subView(20, 2);
        }
    }

    OUString sTimeZoneString;
    if (sTimeZoneMark == "+" || sTimeZoneString == "-")
        sTimeZoneString = sTimeZoneMark + sTimeZoneHours + ":" + sTimeZoneMinutes;
    else if (sTimeZoneMark == "Z")
        sTimeZoneString = sTimeZoneMark;

    return OUString::Concat(sYear) + "-" + sMonth + "-" + sDay + "T" + sHours + ":" + sMinutes + ":"
           + sSeconds + sTimeZoneString;
}
} // end vcl::pdf

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-7.6.1.2.tar.xz: libreoffice-7.6.1.2/vcl/source/pdf/PDFiumTools.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 */

#include <vcl/filter/PDFiumLibrary.hxx>

namespace vcl::pdf
{
OUString convertPdfDateToISO8601(std::u16string_view rInput)
{
    if (rInput.size() < 6)
        return {};

    std::u16string_view prefix = rInput.substr(0, 2);
    if (prefix != u"D:")
        return {};

    std::u16string_view sYear = rInput.substr(2, 4);

    std::u16string_view sMonth(u"01");
    if (rInput.size() >= 8)
        sMonth = rInput.substr(6, 2);

    std::u16string_view sDay(u"01");
    if (rInput.size() >= 10)
        sDay = rInput.substr(8, 2);

    std::u16string_view sHours(u"00");
    if (rInput.size() >= 12)
        sHours = rInput.substr(10, 2);

    std::u16string_view sMinutes(u"00");
    if (rInput.size() >= 14)
        sMinutes = rInput.substr(12, 2);

    std::u16string_view sSeconds(u"00");
    if (rInput.size() >= 16)
        sSeconds = rInput.substr(14, 2);

    OUString sTimeZoneMark("Z");
    if (rInput.size() >= 17)
        sTimeZoneMark = rInput.substr(16, 1);

    std::u16string_view sTimeZoneHours(u"00");
    std::u16string_view sTimeZoneMinutes(u"00");
    if ((sTimeZoneMark == "+" || sTimeZoneMark == "-") && rInput.size() >= 22)
    {
        std::u16string_view sTimeZoneSeparator = rInput.substr(19, 1);
        if (sTimeZoneSeparator == u"'")
        {
            sTimeZoneHours = rInput.substr(17, 2);
            sTimeZoneMinutes = rInput.substr(20, 2);
        }
    }

    OUString sTimeZoneString;
    if (sTimeZoneMark == "+" || sTimeZoneString == "-")
        sTimeZoneString = sTimeZoneMark + sTimeZoneHours + ":" + sTimeZoneMinutes;
    else if (sTimeZoneMark == "Z")
        sTimeZoneString = sTimeZoneMark;

    return OUString::Concat(sYear) + "-" + sMonth + "-" + sDay + "T" + sHours + ":" + sMinutes + ":"
           + sSeconds + sTimeZoneString;
}
} // end vcl::pdf

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
